@@ -1,6 +1,9 @@
 <?xml version='1.0' encoding='ISO-8859-1' ?>
 <!--
-*     Copyright  2006 Sun Microsystems, Inc. All rights reserved.
+*     Copyright © 2010 Oracle and/or its affiliates. All rights reserved.
+
+Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+Other names may be trademarks of their respective owners.
 *     Use is subject to license terms.
 -->
 <!DOCTYPE helpset
@@ -12,35 +15,29 @@
 
   <!-- title -->
   <title>Tomcat Plugin</title>
-  
+
   <!-- maps -->
   <maps>
      <homeID>tomcat_plugin</homeID>
      <mapref location="tomcatMap.jhm" />
   </maps>
-  
+
   <!-- views -->
   <view>
     <name>TOC</name>
     <label>Table Of Contents</label>
     <type>javax.help.TOCView</type>
-    <data>tomcat-toc.xml</data> 
-  </view>
- 
-  <view>
-    <name>Index</name>
-    <label>Index</label>
-    <type>javax.help.IndexView</type>
-    <data>tomcat-idx.xml</data>
+    <data>tomcat-toc.xml</data>
   </view>
 
+
   <view>
     <name>Search</name>
     <label>Search</label>
-    <type>javax.help.SearchView</type> 
-    <data engine="com.sun.java.help.search.DefaultSearchEngine">      
+    <type>javax.help.SearchView</type>
+    <data engine="com.sun.java.help.search.DefaultSearchEngine">
       JavaHelpSearch
-    </data>  
+    </data>
   </view>
 
 </helpset>
